use std::{error::Error, path::PathBuf};

use clap::{Parser, Subcommand};
use pcap::Capture;

fn main() -> Result<(), Box<dyn Error>> {
	let Args { file, cmd } = Args::parse();
	let mut pcap = Capture::from_file(file)?;

	match cmd {
		Cmd::Links => {
			for record in pcap.list_datalinks()? {
				let name = record.get_name().unwrap_or_else(|_| "<unnamed>".into());
				let description = record.get_description().unwrap_or_default();
				println!("link  {name}  {description}")
			}
		}

		Cmd::Stats => {
			let mut total_ipv4 = 0;
			let mut total = 0;
			while let Ok(packet) = pcap.next_packet() {
				total += 1;
				let ether_type = &packet.data[20..][..2];
				if ether_type == [0x00, 0x08] {
					total_ipv4 += 1;
				}
			}
			println!("Count:      {total: >9}");
			println!("Count IPv4: {total_ipv4: >9}");
		}
	}

	Ok(())
}

#[derive(Parser)]
struct Args {
	file: PathBuf,

	#[command(subcommand)]
	cmd: Cmd,
}

#[derive(Subcommand)]
enum Cmd {
	Links,
	Stats,
}
